# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from harmony_connect_client.api_client import ApiClient


class ChainsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_chain_by_id(self, chain_id, **kwargs):  # noqa: E501
        """Get Chain Info  # noqa: E501

        Get information about a specific chain on Connect  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chain_by_id(chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :return: Chain
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_chain_by_id_with_http_info(chain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_chain_by_id_with_http_info(chain_id, **kwargs)  # noqa: E501
            return data

    def get_chain_by_id_with_http_info(self, chain_id, **kwargs):  # noqa: E501
        """Get Chain Info  # noqa: E501

        Get information about a specific chain on Connect  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chain_by_id_with_http_info(chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :return: Chain
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['chain_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_chain_by_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in local_var_params or
                local_var_params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `get_chain_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in local_var_params:
            path_params['chain_id'] = local_var_params['chain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AppId', 'AppKey']  # noqa: E501

        return self.api_client.call_api(
            '/chains/{chain_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Chain',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_chains(self, **kwargs):  # noqa: E501
        """Get All Chains  # noqa: E501

        Returns all of the chains on factomd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chains(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: The number of items you would like back in each page.
        :param int offset: The offset parameter allows you to select which item you would like to start from when you get back a list from Connect. For example, if you've already seen the first 15 items and you'd like the next set, you would send an offset of 15. `offset=0` starts from the first item of the set and is the default position.
        :param str stages: The immutability stages you want to restrict results to. You can choose any from `replicated`, `factom`, and `anchored`. If you would like to search among multiple stages, send them in a comma separated string. For example: `'replicated,factom'`.
        :return: ChainList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_chains_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_chains_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_chains_with_http_info(self, **kwargs):  # noqa: E501
        """Get All Chains  # noqa: E501

        Returns all of the chains on factomd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chains_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int limit: The number of items you would like back in each page.
        :param int offset: The offset parameter allows you to select which item you would like to start from when you get back a list from Connect. For example, if you've already seen the first 15 items and you'd like the next set, you would send an offset of 15. `offset=0` starts from the first item of the set and is the default position.
        :param str stages: The immutability stages you want to restrict results to. You can choose any from `replicated`, `factom`, and `anchored`. If you would like to search among multiple stages, send them in a comma separated string. For example: `'replicated,factom'`.
        :return: ChainList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['limit', 'offset', 'stages']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_chains" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params:
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params:
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'stages' in local_var_params:
            query_params.append(('stages', local_var_params['stages']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AppId', 'AppKey']  # noqa: E501

        return self.api_client.call_api(
            '/chains', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ChainList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_chain(self, chain_create, **kwargs):  # noqa: E501
        """Create a Chain  # noqa: E501

        Create a new chain. Each chain functions as a mini-blockchain such that all of the entries are linked. Every entry relies on data from previous entries in the chain. Any unauthorized alterations to any of these entries can be detected. Be aware that data entered into the `content` and `external_ids` fields must be in Base64 format. Sending this request will cause Connect to create the first entry of the chain. The data entered into the `content` and `external_id` fields will be applied to this entry.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_chain(chain_create, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ChainCreate chain_create: (required)
        :return: ChainShort
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_chain_with_http_info(chain_create, **kwargs)  # noqa: E501
        else:
            (data) = self.post_chain_with_http_info(chain_create, **kwargs)  # noqa: E501
            return data

    def post_chain_with_http_info(self, chain_create, **kwargs):  # noqa: E501
        """Create a Chain  # noqa: E501

        Create a new chain. Each chain functions as a mini-blockchain such that all of the entries are linked. Every entry relies on data from previous entries in the chain. Any unauthorized alterations to any of these entries can be detected. Be aware that data entered into the `content` and `external_ids` fields must be in Base64 format. Sending this request will cause Connect to create the first entry of the chain. The data entered into the `content` and `external_id` fields will be applied to this entry.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_chain_with_http_info(chain_create, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ChainCreate chain_create: (required)
        :return: ChainShort
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['chain_create']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_chain" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'chain_create' is set
        if ('chain_create' not in local_var_params or
                local_var_params['chain_create'] is None):
            raise ValueError("Missing the required parameter `chain_create` when calling `post_chain`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'chain_create' in local_var_params:
            body_params = local_var_params['chain_create']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AppId', 'AppKey']  # noqa: E501

        return self.api_client.call_api(
            '/chains', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ChainShort',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_chain_search(self, search_body, **kwargs):  # noqa: E501
        """Search Chains  # noqa: E501

        Finds all of the chains with `external_ids` that match what you've entered. External IDs must be sent in Base64 format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_chain_search(search_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchBody search_body: (required)
        :param int limit: The number of items you would like back in each page.
        :param int offset: The offset parameter allows you to select which item you would like to start from when you get back a list from Connect. For example, if you've already seen the first 15 items and you'd like the next set, you would send an offset of 15. `offset=0` starts from the first item of the set and is the default position.
        :return: ChainList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_chain_search_with_http_info(search_body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_chain_search_with_http_info(search_body, **kwargs)  # noqa: E501
            return data

    def post_chain_search_with_http_info(self, search_body, **kwargs):  # noqa: E501
        """Search Chains  # noqa: E501

        Finds all of the chains with `external_ids` that match what you've entered. External IDs must be sent in Base64 format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_chain_search_with_http_info(search_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchBody search_body: (required)
        :param int limit: The number of items you would like back in each page.
        :param int offset: The offset parameter allows you to select which item you would like to start from when you get back a list from Connect. For example, if you've already seen the first 15 items and you'd like the next set, you would send an offset of 15. `offset=0` starts from the first item of the set and is the default position.
        :return: ChainList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['search_body', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_chain_search" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'search_body' is set
        if ('search_body' not in local_var_params or
                local_var_params['search_body'] is None):
            raise ValueError("Missing the required parameter `search_body` when calling `post_chain_search`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params:
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params:
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'search_body' in local_var_params:
            body_params = local_var_params['search_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AppId', 'AppKey']  # noqa: E501

        return self.api_client.call_api(
            '/chains/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ChainList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from harmony_connect_client.api.chains_api import ChainsApi
from harmony_connect_client.api.entries_api import EntriesApi
from harmony_connect_client.api.info_api import InfoApi



# coding: utf-8

# flake8: noqa

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.7"

# import apis into sdk package
from harmony_connect_client.api.chains_api import ChainsApi
from harmony_connect_client.api.entries_api import EntriesApi
from harmony_connect_client.api.info_api import InfoApi

# import ApiClient
from harmony_connect_client.api_client import ApiClient
from harmony_connect_client.configuration import Configuration
# import models into sdk package
from harmony_connect_client.models.all_info import AllInfo
from harmony_connect_client.models.all_info_links import AllInfoLinks
from harmony_connect_client.models.chain import Chain
from harmony_connect_client.models.chain_create import ChainCreate
from harmony_connect_client.models.chain_data import ChainData
from harmony_connect_client.models.chain_data_dblock import ChainDataDblock
from harmony_connect_client.models.chain_data_eblock import ChainDataEblock
from harmony_connect_client.models.chain_data_entries import ChainDataEntries
from harmony_connect_client.models.chain_link import ChainLink
from harmony_connect_client.models.chain_list import ChainList
from harmony_connect_client.models.chain_list_data import ChainListData
from harmony_connect_client.models.chain_short import ChainShort
from harmony_connect_client.models.entry import Entry
from harmony_connect_client.models.entry_create import EntryCreate
from harmony_connect_client.models.entry_data import EntryData
from harmony_connect_client.models.entry_data_dblock import EntryDataDblock
from harmony_connect_client.models.entry_data_eblock import EntryDataEblock
from harmony_connect_client.models.entry_list import EntryList
from harmony_connect_client.models.entry_list_chain import EntryListChain
from harmony_connect_client.models.entry_list_data import EntryListData
from harmony_connect_client.models.entry_search_response import EntrySearchResponse
from harmony_connect_client.models.entry_search_response_data import EntrySearchResponseData
from harmony_connect_client.models.entry_short import EntryShort
from harmony_connect_client.models.search_body import SearchBody



# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from harmony_connect_client.api_client import ApiClient


class EntriesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_entries_by_chain_id(self, chain_id, **kwargs):  # noqa: E501
        """Get Chain's Entries  # noqa: E501

        List all entries contained on the specified chain.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entries_by_chain_id(chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :param int limit: The number of items you would like back in each page.
        :param int offset: The offset parameter allows you to select which item you would like to start from when you get back a list from Connect. For example, if you've already seen the first 15 items and you'd like the next set, you would send an offset of 15. `offset=0` starts from the first item of the set and is the default position.
        :param str stages: The immutability stages you want to restrict results to. You can choose any from `replicated`, `factom`, and `anchored`. If you would like to search among multiple stages, send them in a comma separated string. For example: `'replicated,factom'`.
        :return: EntryList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_entries_by_chain_id_with_http_info(chain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_entries_by_chain_id_with_http_info(chain_id, **kwargs)  # noqa: E501
            return data

    def get_entries_by_chain_id_with_http_info(self, chain_id, **kwargs):  # noqa: E501
        """Get Chain's Entries  # noqa: E501

        List all entries contained on the specified chain.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entries_by_chain_id_with_http_info(chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :param int limit: The number of items you would like back in each page.
        :param int offset: The offset parameter allows you to select which item you would like to start from when you get back a list from Connect. For example, if you've already seen the first 15 items and you'd like the next set, you would send an offset of 15. `offset=0` starts from the first item of the set and is the default position.
        :param str stages: The immutability stages you want to restrict results to. You can choose any from `replicated`, `factom`, and `anchored`. If you would like to search among multiple stages, send them in a comma separated string. For example: `'replicated,factom'`.
        :return: EntryList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['chain_id', 'limit', 'offset', 'stages']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_entries_by_chain_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in local_var_params or
                local_var_params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `get_entries_by_chain_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in local_var_params:
            path_params['chain_id'] = local_var_params['chain_id']  # noqa: E501

        query_params = []
        if 'limit' in local_var_params:
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params:
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'stages' in local_var_params:
            query_params.append(('stages', local_var_params['stages']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AppId', 'AppKey']  # noqa: E501

        return self.api_client.call_api(
            '/chains/{chain_id}/entries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EntryList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_entry_by_hash(self, chain_id, entry_hash, **kwargs):  # noqa: E501
        """Get Entry Info  # noqa: E501

        Returns information about a specific entry on Connect. The requested entry must be specified using the Chain ID and Entry Hash.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entry_by_hash(chain_id, entry_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :param str entry_hash: The SHA256 hash of the entry. (required)
        :return: Entry
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_entry_by_hash_with_http_info(chain_id, entry_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.get_entry_by_hash_with_http_info(chain_id, entry_hash, **kwargs)  # noqa: E501
            return data

    def get_entry_by_hash_with_http_info(self, chain_id, entry_hash, **kwargs):  # noqa: E501
        """Get Entry Info  # noqa: E501

        Returns information about a specific entry on Connect. The requested entry must be specified using the Chain ID and Entry Hash.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entry_by_hash_with_http_info(chain_id, entry_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :param str entry_hash: The SHA256 hash of the entry. (required)
        :return: Entry
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['chain_id', 'entry_hash']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_entry_by_hash" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in local_var_params or
                local_var_params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `get_entry_by_hash`")  # noqa: E501
        # verify the required parameter 'entry_hash' is set
        if ('entry_hash' not in local_var_params or
                local_var_params['entry_hash'] is None):
            raise ValueError("Missing the required parameter `entry_hash` when calling `get_entry_by_hash`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in local_var_params:
            path_params['chain_id'] = local_var_params['chain_id']  # noqa: E501
        if 'entry_hash' in local_var_params:
            path_params['entry_hash'] = local_var_params['entry_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AppId', 'AppKey']  # noqa: E501

        return self.api_client.call_api(
            '/chains/{chain_id}/entries/{entry_hash}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Entry',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_first_entry(self, chain_id, **kwargs):  # noqa: E501
        """Get Chain's First Entry  # noqa: E501

        Retrieve the first entry that has been saved to this chain.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_first_entry(chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :return: Entry
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_first_entry_with_http_info(chain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_first_entry_with_http_info(chain_id, **kwargs)  # noqa: E501
            return data

    def get_first_entry_with_http_info(self, chain_id, **kwargs):  # noqa: E501
        """Get Chain's First Entry  # noqa: E501

        Retrieve the first entry that has been saved to this chain.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_first_entry_with_http_info(chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :return: Entry
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['chain_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_first_entry" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in local_var_params or
                local_var_params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `get_first_entry`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in local_var_params:
            path_params['chain_id'] = local_var_params['chain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AppId', 'AppKey']  # noqa: E501

        return self.api_client.call_api(
            '/chains/{chain_id}/entries/first', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Entry',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_last_entry(self, chain_id, **kwargs):  # noqa: E501
        """Get Chain's Last Entry  # noqa: E501

        Retrieve the last entry that has been saved to this chain.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_last_entry(chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :return: Entry
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_last_entry_with_http_info(chain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_last_entry_with_http_info(chain_id, **kwargs)  # noqa: E501
            return data

    def get_last_entry_with_http_info(self, chain_id, **kwargs):  # noqa: E501
        """Get Chain's Last Entry  # noqa: E501

        Retrieve the last entry that has been saved to this chain.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_last_entry_with_http_info(chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :return: Entry
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['chain_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_last_entry" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in local_var_params or
                local_var_params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `get_last_entry`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in local_var_params:
            path_params['chain_id'] = local_var_params['chain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AppId', 'AppKey']  # noqa: E501

        return self.api_client.call_api(
            '/chains/{chain_id}/entries/last', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Entry',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_entries_search(self, chain_id, search_body, **kwargs):  # noqa: E501
        """Search Chain's Entries  # noqa: E501

        Find all of the entries within the specified chain that have the requested `external_ids`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_entries_search(chain_id, search_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :param SearchBody search_body: (required)
        :param int limit: The number of items you would like back in each page.
        :param int offset: The offset parameter allows you to select which item you would like to start from when you get back a list from Connect. For example, if you've already seen the first 15 items and you'd like the next set, you would send an offset of 15. `offset=0` starts from the first item of the set and is the default position.
        :return: EntrySearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_entries_search_with_http_info(chain_id, search_body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_entries_search_with_http_info(chain_id, search_body, **kwargs)  # noqa: E501
            return data

    def post_entries_search_with_http_info(self, chain_id, search_body, **kwargs):  # noqa: E501
        """Search Chain's Entries  # noqa: E501

        Find all of the entries within the specified chain that have the requested `external_ids`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_entries_search_with_http_info(chain_id, search_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :param SearchBody search_body: (required)
        :param int limit: The number of items you would like back in each page.
        :param int offset: The offset parameter allows you to select which item you would like to start from when you get back a list from Connect. For example, if you've already seen the first 15 items and you'd like the next set, you would send an offset of 15. `offset=0` starts from the first item of the set and is the default position.
        :return: EntrySearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['chain_id', 'search_body', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_entries_search" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in local_var_params or
                local_var_params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `post_entries_search`")  # noqa: E501
        # verify the required parameter 'search_body' is set
        if ('search_body' not in local_var_params or
                local_var_params['search_body'] is None):
            raise ValueError("Missing the required parameter `search_body` when calling `post_entries_search`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in local_var_params:
            path_params['chain_id'] = local_var_params['chain_id']  # noqa: E501

        query_params = []
        if 'limit' in local_var_params:
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params:
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'search_body' in local_var_params:
            body_params = local_var_params['search_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AppId', 'AppKey']  # noqa: E501

        return self.api_client.call_api(
            '/chains/{chain_id}/entries/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EntrySearchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_entry_to_chain_id(self, chain_id, entry_create, **kwargs):  # noqa: E501
        """Create an Entry  # noqa: E501

        Create a new entry for the selected chain. Content and external id must be uploaded in Base64 format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_entry_to_chain_id(chain_id, entry_create, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :param EntryCreate entry_create: (required)
        :return: EntryShort
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_entry_to_chain_id_with_http_info(chain_id, entry_create, **kwargs)  # noqa: E501
        else:
            (data) = self.post_entry_to_chain_id_with_http_info(chain_id, entry_create, **kwargs)  # noqa: E501
            return data

    def post_entry_to_chain_id_with_http_info(self, chain_id, entry_create, **kwargs):  # noqa: E501
        """Create an Entry  # noqa: E501

        Create a new entry for the selected chain. Content and external id must be uploaded in Base64 format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_entry_to_chain_id_with_http_info(chain_id, entry_create, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: Chain identifier (required)
        :param EntryCreate entry_create: (required)
        :return: EntryShort
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['chain_id', 'entry_create']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_entry_to_chain_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in local_var_params or
                local_var_params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `post_entry_to_chain_id`")  # noqa: E501
        # verify the required parameter 'entry_create' is set
        if ('entry_create' not in local_var_params or
                local_var_params['entry_create'] is None):
            raise ValueError("Missing the required parameter `entry_create` when calling `post_entry_to_chain_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in local_var_params:
            path_params['chain_id'] = local_var_params['chain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'entry_create' in local_var_params:
            body_params = local_var_params['entry_create']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AppId', 'AppKey']  # noqa: E501

        return self.api_client.call_api(
            '/chains/{chain_id}/entries', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EntryShort',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EntrySearchResponseData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'entry_hash': 'str',
        'external_ids': 'list[str]',
        'stage': 'str',
        'href': 'str'
    }

    attribute_map = {
        'entry_hash': 'entry_hash',
        'external_ids': 'external_ids',
        'stage': 'stage',
        'href': 'href'
    }

    def __init__(self, entry_hash=None, external_ids=None, stage=None, href=None):  # noqa: E501
        """EntrySearchResponseData - a model defined in OpenAPI"""  # noqa: E501

        self._entry_hash = None
        self._external_ids = None
        self._stage = None
        self._href = None
        self.discriminator = None

        self.entry_hash = entry_hash
        self.external_ids = external_ids
        self.stage = stage
        self.href = href

    @property
    def entry_hash(self):
        """Gets the entry_hash of this EntrySearchResponseData.  # noqa: E501

        The SHA256 Hash of this entry.  # noqa: E501

        :return: The entry_hash of this EntrySearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._entry_hash

    @entry_hash.setter
    def entry_hash(self, entry_hash):
        """Sets the entry_hash of this EntrySearchResponseData.

        The SHA256 Hash of this entry.  # noqa: E501

        :param entry_hash: The entry_hash of this EntrySearchResponseData.  # noqa: E501
        :type: str
        """
        if entry_hash is None:
            raise ValueError("Invalid value for `entry_hash`, must not be `None`")  # noqa: E501

        self._entry_hash = entry_hash

    @property
    def external_ids(self):
        """Gets the external_ids of this EntrySearchResponseData.  # noqa: E501

        Tags that can be used to identify this entry.  # noqa: E501

        :return: The external_ids of this EntrySearchResponseData.  # noqa: E501
        :rtype: list[str]
        """
        return self._external_ids

    @external_ids.setter
    def external_ids(self, external_ids):
        """Sets the external_ids of this EntrySearchResponseData.

        Tags that can be used to identify this entry.  # noqa: E501

        :param external_ids: The external_ids of this EntrySearchResponseData.  # noqa: E501
        :type: list[str]
        """
        if external_ids is None:
            raise ValueError("Invalid value for `external_ids`, must not be `None`")  # noqa: E501

        self._external_ids = external_ids

    @property
    def stage(self):
        """Gets the stage of this EntrySearchResponseData.  # noqa: E501

        The level of immutability that this entry has reached.  # noqa: E501

        :return: The stage of this EntrySearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._stage

    @stage.setter
    def stage(self, stage):
        """Sets the stage of this EntrySearchResponseData.

        The level of immutability that this entry has reached.  # noqa: E501

        :param stage: The stage of this EntrySearchResponseData.  # noqa: E501
        :type: str
        """
        if stage is None:
            raise ValueError("Invalid value for `stage`, must not be `None`")  # noqa: E501

        self._stage = stage

    @property
    def href(self):
        """Gets the href of this EntrySearchResponseData.  # noqa: E501

        An API link to retrieve all information about this entry.  # noqa: E501

        :return: The href of this EntrySearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this EntrySearchResponseData.

        An API link to retrieve all information about this entry.  # noqa: E501

        :param href: The href of this EntrySearchResponseData.  # noqa: E501
        :type: str
        """
        if href is None:
            raise ValueError("Invalid value for `href`, must not be `None`")  # noqa: E501

        self._href = href

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EntrySearchResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import harmony_connect_client
from harmony_connect_client.api.entries_api import EntriesApi  # noqa: E501
from harmony_connect_client.rest import ApiException


class TestEntriesApi(unittest.TestCase):
    """EntriesApi unit test stubs"""

    def setUp(self):
        self.api = harmony_connect_client.api.entries_api.EntriesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_entries_by_chain_id(self):
        """Test case for get_entries_by_chain_id

        Get Chain's Entries  # noqa: E501
        """
        pass

    def test_get_entry_by_hash(self):
        """Test case for get_entry_by_hash

        Get Entry Info  # noqa: E501
        """
        pass

    def test_get_first_entry(self):
        """Test case for get_first_entry

        Get Chain's First Entry  # noqa: E501
        """
        pass

    def test_get_last_entry(self):
        """Test case for get_last_entry

        Get Chain's Last Entry  # noqa: E501
        """
        pass

    def test_post_entries_search(self):
        """Test case for post_entries_search

        Search Chain's Entries  # noqa: E501
        """
        pass

    def test_post_entry_to_chain_id(self):
        """Test case for post_entry_to_chain_id

        Create an Entry  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import harmony_connect_client
from harmony_connect_client.models.chain_data_eblock import ChainDataEblock  # noqa: E501
from harmony_connect_client.rest import ApiException


class TestChainDataEblock(unittest.TestCase):
    """ChainDataEblock unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testChainDataEblock(self):
        """Test ChainDataEblock"""
        # FIXME: construct object with mandatory attributes with example values
        # model = harmony_connect_client.models.chain_data_eblock.ChainDataEblock()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import harmony_connect_client
from harmony_connect_client.api.chains_api import ChainsApi  # noqa: E501
from harmony_connect_client.rest import ApiException


class TestChainsApi(unittest.TestCase):
    """ChainsApi unit test stubs"""

    def setUp(self):
        self.api = harmony_connect_client.api.chains_api.ChainsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_chain_by_id(self):
        """Test case for get_chain_by_id

        Get Chain Info  # noqa: E501
        """
        pass

    def test_get_chains(self):
        """Test case for get_chains

        Get All Chains  # noqa: E501
        """
        pass

    def test_post_chain(self):
        """Test case for post_chain

        Create a Chain  # noqa: E501
        """
        pass

    def test_post_chain_search(self):
        """Test case for post_chain_search

        Search Chains  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "harmony-connect-client"
VERSION = "1.0.7"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Harmony Connect",
    author_email="harmony-support@factom.com",
    url="https://github.com/FactomProject/factom-harmony-connect-python-client",
    keywords=["factom", "factom-blockchain", "blockchain", "blockchain-as-a-service", "client-library", "Harmony Connect"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
=============================
Harmony Connect Client
=============================

Harmony Connect is your fast lane to the blockchain. Add blockchain capabilities to any software without needing to wrestle with currencies, wallets, or blockchain nodes. Instead, you get easy read and write access to the Factom blockchain. Connect will also track your data's path to immutability and will notify you along the way.


============
Requirements
============

Python 2.7 and 3.4+

====================
Installation & Usage
====================

***********
pip install
***********

You can install the package hosted on PyPi by using pip:

``pip install harmony_connect_client``

Then import the package:
``import harmony_connect_client``


You can also install the Harmony Connect client directly from Github


``pip install git+https://github.com/FactomProject/factom-harmony-connect-python-client.git``

(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/FactomProject/factom-harmony-connect-python-client.git`)

**********
Setuptools
**********

Install via `Setuptools <http://pypi.python.org/pypi/setuptools>`_.


``python setup.py install --user``

(or `sudo python setup.py install` to install the package for all users)

Then import the package:
``import harmony_connect_client``

=============================
Harmony Connect Documentation
=============================
This client is built to communicate with Factom Harmony Connect. For more information about using this API, please visit the Harmony Connect `documentation <https://docs.harmony.factom.com>`_.

You can create a free account at `Factom.com <https://account.factom.com>`_.
    """
)



# coding: utf-8

"""
    Harmony Connect

    An easy to use API that helps you access the Factom blockchain.  # noqa: E501

    OpenAPI spec version: 1.0.17
    Contact: harmony-support@factom.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class ChainCreate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'external_ids': 'list[str]',
        'content': 'str',
        'callback_url': 'str',
        'callback_stages': 'list[str]'
    }

    attribute_map = {
        'external_ids': 'external_ids',
        'content': 'content',
        'callback_url': 'callback_url',
        'callback_stages': 'callback_stages'
    }

    def __init__(self, external_ids=None, content=None, callback_url=None, callback_stages=None):  # noqa: E501
        """ChainCreate - a model defined in OpenAPI"""  # noqa: E501

        self._external_ids = None
        self._content = None
        self._callback_url = None
        self._callback_stages = None
        self.discriminator = None

        self.external_ids = external_ids
        self.content = content
        if callback_url is not None:
            self.callback_url = callback_url
        if callback_stages is not None:
            self.callback_stages = callback_stages

    @property
    def external_ids(self):
        """Gets the external_ids of this ChainCreate.  # noqa: E501

        Tags that can be used to identify your chain. You can search for records that contain a particular external_id using Connect. You must send External IDs in Base64 format.  # noqa: E501

        :return: The external_ids of this ChainCreate.  # noqa: E501
        :rtype: list[str]
        """
        return self._external_ids

    @external_ids.setter
    def external_ids(self, external_ids):
        """Sets the external_ids of this ChainCreate.

        Tags that can be used to identify your chain. You can search for records that contain a particular external_id using Connect. You must send External IDs in Base64 format.  # noqa: E501

        :param external_ids: The external_ids of this ChainCreate.  # noqa: E501
        :type: list[str]
        """
        if external_ids is None:
            raise ValueError("Invalid value for `external_ids`, must not be `None`")  # noqa: E501

        self._external_ids = external_ids

    @property
    def content(self):
        """Gets the content of this ChainCreate.  # noqa: E501

        This is the data that will make up the first entry in your new chain. It is customary to use this space to describe the entries that are to follow in the chain. You must send the content field in Base64 format.  # noqa: E501

        :return: The content of this ChainCreate.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this ChainCreate.

        This is the data that will make up the first entry in your new chain. It is customary to use this space to describe the entries that are to follow in the chain. You must send the content field in Base64 format.  # noqa: E501

        :param content: The content of this ChainCreate.  # noqa: E501
        :type: str
        """
        if content is None:
            raise ValueError("Invalid value for `content`, must not be `None`")  # noqa: E501

        self._content = content

    @property
    def callback_url(self):
        """Gets the callback_url of this ChainCreate.  # noqa: E501

        The URL where you would like to receive the callback from Connect. If this is not specified, callbacks will not activate.  # noqa: E501

        :return: The callback_url of this ChainCreate.  # noqa: E501
        :rtype: str
        """
        return self._callback_url

    @callback_url.setter
    def callback_url(self, callback_url):
        """Sets the callback_url of this ChainCreate.

        The URL where you would like to receive the callback from Connect. If this is not specified, callbacks will not activate.  # noqa: E501

        :param callback_url: The callback_url of this ChainCreate.  # noqa: E501
        :type: str
        """

        self._callback_url = callback_url

    @property
    def callback_stages(self):
        """Gets the callback_stages of this ChainCreate.  # noqa: E501

        The stages that you would like to trigger a callback from Connect. This list can include any or all of the three stages: `replicated`, `factom`, and `anchored`. If callbacks are activated and this field is not sent, it will default to `factom` and `anchored`  # noqa: E501

        :return: The callback_stages of this ChainCreate.  # noqa: E501
        :rtype: list[str]
        """
        return self._callback_stages

    @callback_stages.setter
    def callback_stages(self, callback_stages):
        """Sets the callback_stages of this ChainCreate.

        The stages that you would like to trigger a callback from Connect. This list can include any or all of the three stages: `replicated`, `factom`, and `anchored`. If callbacks are activated and this field is not sent, it will default to `factom` and `anchored`  # noqa: E501

        :param callback_stages: The callback_stages of this ChainCreate.  # noqa: E501
        :type: list[str]
        """

        self._callback_stages = callback_stages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChainCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
